@@ -621,7 +621,9 @@ class DataFrameGroupBy:
         # self._na = DataFrame({k: v.isna() for k, v in self._groups._items()})._to_numeric().any(dim=1)
         # self._row_to_group_idx = ar.Array(inv_idx).like(self._na, dtype=False)
         
-        arr = data._to_numeric().to(device, force=True) # numeric array representation of selected columns
+        arr = data._to_numeric() # numeric array representation of selected columns
+        if device is not None:
+            arr = arr.to(device, force=True) # use device if device is not None
         if arr.is_masked_array:
             arr = arr.asndarray() # ma.MaskedArray currently does not support unique
         _, idx, inv_idx = arr.unique(sorted=sort, return_index=True, return_inverse=True, dim=0)
